@@ -1,14 +1,15 @@
 /*
  * $Header$
- * $Revision: 155418 $
- * $Date: 2005-02-26 08:01:52 -0500 (Sat, 26 Feb 2005) $
+ * $Revision: 480424 $
+ * $Date: 2006-11-29 06:56:49 +0100 (Wed, 29 Nov 2006) $
  * ====================================================================
  *
- *  Copyright 2002-2004 The Apache Software Foundation
- *
- *  Licensed under the Apache License, Version 2.0 (the "License");
- *  you may not use this file except in compliance with the License.
- *  You may obtain a copy of the License at
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
  *
  *      http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -176,7 +177,7 @@ public class MultipartFileUploadApp {
                             );
                         }
                     } catch (Exception ex) {
-                        appendMessage("Error: " + ex.getMessage());
+                        appendMessage("ERROR: " + ex.getClass().getName() + " "+ ex.getMessage());
                         ex.printStackTrace();
                     } finally {
                         filePost.releaseConnection();
