@@ -1,14 +1,15 @@
 /*
  * $Header: /home/jerenkrantz/tmp/commons/commons-convert/cvs/home/cvs/jakarta-commons//httpclient/src/test/org/apache/commons/httpclient/TestHttpConnectionManager.java,v 1.23 2004/07/17 18:58:33 mbecke Exp $
- * $Revision: 312494 $
- * $Date: 2005-10-09 15:53:32 -0400 (Sun, 09 Oct 2005) $
+ * $Revision: 509320 $
+ * $Date: 2007-02-19 20:52:43 +0100 (Mon, 19 Feb 2007) $
  * ====================================================================
  *
- *  Copyright 1999-2004 The Apache Software Foundation
- *
- *  Licensed under the Apache License, Version 2.0 (the "License");
- *  you may not use this file except in compliance with the License.
- *  You may obtain a copy of the License at
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
  *
  *      http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -49,7 +50,7 @@ import org.apache.commons.httpclient.server.SimpleResponse;
  * Unit tests for {@link HttpConnectionManager}.
  *
  * @author Marc A. Saegesser
- * @version $Id: TestHttpConnectionManager.java 312494 2005-10-09 19:53:32Z olegk $
+ * @version $Id: TestHttpConnectionManager.java 509320 2007-02-19 19:52:43Z mbecke $
  */
 public class TestHttpConnectionManager extends HttpClientTestBase {
 
@@ -654,6 +655,59 @@ public class TestHttpConnectionManager extends HttpClientTestBase {
         assertEquals("connectionsInPool(host)", manager.getConnectionsInPool(client.getHostConfiguration()), 0);
     }
     
+    /**
+     * Tests that thread waiting in the MultiThreadedHttpConnectionManager can be 
+     * interrupted.
+     */
+    public void testWaitingThreadInterrupted() {
+
+        this.server.setHttpService(new EchoService());
+
+        MultiThreadedHttpConnectionManager connectionManager = new MultiThreadedHttpConnectionManager();
+        connectionManager.getParams().setIntParameter(
+            HttpConnectionManagerParams.MAX_TOTAL_CONNECTIONS, 1);
+
+        HostConfiguration host1 = new HostConfiguration();
+        host1.setHost("host1", -1, "http");
+
+        // hold on to the only connection
+        HttpConnection connection = connectionManager.getConnection(host1);
+
+        // wait for a connection on another thread
+        GetConnectionThread getConn = new GetConnectionThread(host1, connectionManager, 1000);
+        getConn.start();
+        
+        // give the thread a chance to block
+        synchronized (this) {
+            try {
+                this.wait(500);
+            } catch (InterruptedException e) {
+                e.printStackTrace();
+            }
+        }
+        
+        // interrupt the thread, this should cancel waiting with a RuntimeException
+        getConn.interrupt();
+        
+        try {
+            getConn.join();
+        } catch (InterruptedException e) {
+            e.printStackTrace();
+        }
+        
+        // make sure the correct exception was thrown
+        assertTrue(getConn.exception != null);
+        assertEquals(getConn.exception.getClass(), IllegalThreadStateException.class);
+        
+        // make sure the connection manager is still working
+        connection.releaseConnection();
+        try {
+            connectionManager.getConnectionWithTimeout(host1, 10);
+        } catch (ConnectionPoolTimeoutException e) {
+            fail("Connection not available");
+        }
+    }
+    
     public void testReclaimUnusedConnection() {
 
         this.server.setHttpService(new EchoService());
